PROGRAM ADDCR;

{=====================================================================}
{ PURPOSE : Inserts a CR to an input file where ever a LF is found.   }
{           ( ie. translates LF to CR / LF )                          }
{=====================================================================}
{ SYSTEM  : MS-DOS / Turbo Pascal                                     }
{                      Ver. 7.0                                       }
{ Author: Mike Genovy                                                 }
{ Date :  Sept 17, 1996                                               }
{                                                                     }
{=====================================================================}

CONST

   Title    = 'ADDCR - Converts Line Feeds to Carriage Returns / Line Feeds';
   Version  = 'Version 1.00';

{=====================================================================}
{  Processfiles                                                       }
{=====================================================================}

PROCEDURE ProcessFiles;

{ Read text from input file and write to output }

CONST

   Tab   = ^I;  { ASCII tab character   }
   Null  = #00; { ASCII Null character  }
   DC4   = #20; { ASCII DC4 character   }
   RS    = #30; { ASCII RS character    }
   Blank = #32; { ASCII Blank Character }
   CR    = #13; { ASCII Carriage return }
   LF    = #10; { ASCII Line feed       }


VAR
InName    : string;               { Name of input file to be created  }
OutName   : string;               { Name of output file to be created }
OutFileB1 : File;                 { Binary output file                }
InFileB1  : file;                 { Binary input file                 }
ch        : char;                 { Character read from input file    }
Ch1       : char;
ChPrev    : char;
result    : integer;  { Number of characters read from the input file }
PreviousCR  : Boolean;            { Flag to indicate previous ch was a CR }

BEGIN

     WriteLn (' Enter the Input file name ( extension required )');
     ReadLn(InName);
     WriteLn (' Enter the Output file name ( extension required )');
     ReadLn(OutName);

{ Assign the data file names }

   Assign(InFileB1,InName);

   Assign(OutFileB1,OutName);

{ See if the input data file exists - if not exit }

{$i-}

   Reset(InFileB1,1);	{ Open an existing file with a block size }
                        { of one byte                             }
{$i+}

   If IoResult <> 0 then
   begin
     WriteLn;
     WriteLn(InName,'does NOT exist !');
     Write('Program aborting !');
     Exit;
   end;

   WriteLn('Processing the input file ......');

{ Create a new file with a block size of one }

   begin
     Rewrite(OutFileB1,1);
   end;

   Result := 0;

   BlockRead(InFileB1,Ch,1,result); { result = number of bytes read }

   Chprev := ch;                    { Set up the previous character }

repeat

   BlockRead(InFileB1,Ch1,1,result); { result = number of bytes read }

   If Result > 0 then               { If we are not at the end of file }
   begin
     If (Ch1 = LF) and (ChPrev <> CR) then
     begin
         BlockWrite(OutFileB1,ChPrev,1);   { output previous character  }
         Ch := CR;                         { Insert the CR              }
         BlockWrite(OutFileB1,ch,1);
         BlockWrite(OutFileB1,ch1,1);      { and output current LF   }
     end
     else
     begin
         BlockWrite(OutFileB1,ch1,1);      { and output current character }
         ChPrev := Ch1;
     end;
   end;

until result = 0;

{ Close files and exit }

   Close( inFileB1 );
   Close( outFileB1 );

END; { ProcessFiles }

{=====================================================================}
{  Main Routine                                                       }
{=====================================================================}

BEGIN
   WriteLn;
   WriteLn(Title,' - ', Version);
   WriteLn('By Mike Genovy - May 3, 1996');
   ProcessFiles;
END.
